@@ -8,7 +8,7 @@ __PACKAGE__->table('track');
 __PACKAGE__->add_columns(
     qw<
         trackid
-        cd
+        cdid
         position
         title
     >
@@ -16,4 +16,6 @@ __PACKAGE__->add_columns(
 
 __PACKAGE__->set_primary_key('trackid');
 
+__PACKAGE__->belongs_to( cd => 'TDCSTest::Schema::CD', 'cdid' );
+
 1;
